import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import freemarker.template.*;

public class GuestbookServlet extends HttpServlet {

    private Guestbook book;
    private FileTemplateCache templateCache;

    public void init(ServletConfig config) throws ServletException {
        super.init(config);
        templateCache = new FileTemplateCache(this.getClass());
        book = new Guestbook();
    }

    public void doGet(HttpServletRequest req, HttpServletResponse res)
        throws ServletException, IOException {

        res.setContentType("text/html");
        PrintWriter out = res.getWriter();

        // Get the guestbook's template.
        Template template = templateCache.getTemplate("guestbook_template.html");

        // Make the root node of the data model.
        SimpleHash modelRoot = new SimpleHash();

        // If an entry was submitted, add it to the guestbook.
        if (req.getParameter("dataSubmitted") != null) {
            book.addEntry(req.getParameter("guestName"), req.getParameter("message"));
            modelRoot.put("entryAdded", new SimpleScalar(true));
        }

        // Wrap the guestbook in a template model adapter.
        GuestbookTM bookTM = new GuestbookTM(book);
        modelRoot.put("guestbook", bookTM);

        // Process the template.
        try {
        	template.process(modelRoot, out);
        } catch( TemplateException e ) {
            e.printStackTrace(out);
        	// Failure case
        }

        out.close();
    }

    public void doPost(HttpServletRequest req, HttpServletResponse res)
        throws ServletException, IOException {
        doGet(req, res);
    }

    public String getServletInfo() {
        return "Guestbook Servlet";
    }
}
