/*
 * FreeMarker: a tool that allows Java programs to use templates
 * to generate HTML or other text output that contains dynamic content.
 * Copyright (C) 1998,2002 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name "Freemarker" nor any of the names of the project 
 * contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package freemarker.ext.jsp;

import javax.servlet.jsp.tagext.*;

import java.io.*;
import java.util.*;

import javax.servlet.ServletException;
import javax.servlet.jsp.tagext.BodyTag;
import javax.servlet.jsp.tagext.Tag;
import javax.servlet.jsp.tagext.BodyContent;

import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.PageContext;

import freemarker.template.*;

/**
 * Simple implementation of JSP tag to allow use of FreeMarker templates in
 * JSP. Inspired by similar class in Velocity template engine developed by
 * <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
 * @author Attila Szegedi, <a href="mailto:szegedia@freemail.hu">szegedia@freemail.hu</a>
 */
public class FreemarkerTag implements BodyTag
{
    private Tag         parent = null;
    private BodyContent bodyContent = null;
    private PageContext pageContext = null;
    private Template    template = null;
    private boolean     caching = true;

    public boolean getCaching()
    {
        return caching;
    }

    public void setCaching(boolean caching)
    {
        this.caching = caching;
    }

    public Tag getParent()
    {
        return parent;
    }

    public void setParent(Tag parent)
    {
        this.parent = parent;
    }

    public int doStartTag()
    {
        return EVAL_BODY_TAG;
    }

    public void setBodyContent(BodyContent bodyContent)
    {
        this.bodyContent = bodyContent;
    }

    public void setPageContext(PageContext pageContext)
    {
        this.pageContext = pageContext;
    }

    public void doInitBody()
    {
    }

    public int doAfterBody()
    {
        return 0;
    }

    public void release()
    {
    }

    public int doEndTag()
        throws JspException
    {
        if (bodyContent == null)
            return EVAL_PAGE;

        try
        {
            SimpleHash root = new SimpleHash();
            root.put("page", new JspContextModel(pageContext, JspContextModel.PAGE_SCOPE));
            root.put("request", new JspContextModel(pageContext, JspContextModel.REQUEST_SCOPE));
            root.put("session", new JspContextModel(pageContext, JspContextModel.SESSION_SCOPE));
            root.put("application", new JspContextModel(pageContext, JspContextModel.APPLICATION_SCOPE));
            root.put("any", new JspContextModel(pageContext, JspContextModel.ANY_SCOPE));

            if(template == null || !caching)
                template = new Template(bodyContent.getReader());

            template.process(root, pageContext.getOut());
        }
        catch(Exception e)
        {
            try
            {
                pageContext.handlePageException(e);
            }
            catch(ServletException e2)
            {
                throw new JspException(e2.getMessage());
            }
            catch(IOException e2)
            {
                throw new JspException(e2.getMessage());
            }
        }

        return EVAL_PAGE;
    }
}
