/*
 * FreeMarker: a tool that allows Java programs to use templates
 * to generate HTML or other text output that contains dynamic content.
 * Copyright (C) 1998,2002 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name "Freemarker" nor any of the names of the project 
 * contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package freemarker.template.compiler;

import freemarker.template.*;
import java.io.Writer;

/**
 * Represents a &lt;break&gt; instruction to break out of a loop.
 * Also used for &lt;stop&gt; and &lt;return&gt;
 * @author <A HREF="mailto:jon@revusky.com">Jonathan Revusky</A>
 */
final class BreakInstruction extends TemplateElement {

    static final int BREAK = 0;
    static final int RETURN = 1;
    static final int STOP = 2;

    private int type;

    BreakInstruction(int type) {
        this.type = type;
    }

    public void process( TemplateModelRoot modelRoot, Writer out) 
        throws TemplateException 
    {
        if (type == BREAK) {
            throw new Break();
        }
        if (type == RETURN) {
            throw new Return();
        }
        else {
            throw new StopException();
        }
    }

    public String toString() {
        if (type == BREAK) {
            return "<break>";
        } 
        else if (type == RETURN) {
            return "<return>";
        }
        else {
            return "<stop>";
        }
    }

    static class Break extends TemplateException {}

    static class Return extends TemplateException {}
}


