/*
 * FreeMarker: a tool that allows Java programs to use templates
 * to generate HTML or other text output that contains dynamic content.
 * Copyright (C) 1998,2002 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name "Freemarker" nor any of the names of the project 
 * contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package freemarker.template.compiler;

import freemarker.template.*;
import java.util.*;
import java.io.*;

/**
 * An abstract class for nodes in the parse tree 
 * that represent a FreeMarker expression.
 */
abstract public class Expression extends TemplateObject {

    abstract protected TemplateModel getAsTemplateModel(TemplateModelRoot modelRoot)
    throws TemplateException;

    protected String getStringValue(TemplateModelRoot modelRoot) throws TemplateException {
        TemplateModel referentModel = getAsTemplateModel(modelRoot);
        if (referentModel == null || referentModel.isEmpty()) {
            return null;
        }
        if (!(referentModel instanceof TemplateScalarModel)) {
            String msg = "Error " + getLocation()
                        +"\nExpecting scalar here, Expression " + this + " is not a TemlplateScalarModel,"
                        + "it's a " + referentModel.getClass().getName() + ".";
            throw new TemplateException(msg);
        }
        TemplateScalarModel referentScalarModel = (TemplateScalarModel)referentModel;
        return referentScalarModel.getAsString(modelRoot.getLocale());
    }

    protected boolean isTrue(TemplateModelRoot modelRoot) throws TemplateException {
        TemplateModel referent = getAsTemplateModel(modelRoot);
        return !(referent == null || referent.isEmpty());
    }
}
