/*
 * FreeMarker: a tool that allows Java programs to use templates
 * to generate HTML or other text output that contains dynamic content.
 * Copyright (C) 1998,2002 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name "Freemarker" nor any of the names of the project 
 * contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package freemarker.template.compiler;

import java.util.*;
import freemarker.template.*;

final class HashLiteral extends Expression {
    private HashMap map;

    HashLiteral(HashMap map) {
        this.map = map;
    }

    protected String getStringValue(TemplateModelRoot modelRoot) throws TemplateException {
        String msg = "Error " + getLocation() + ". "
            + "\nExpecting scalar here. This is a hash.";
        throw new TemplateException(msg);
    }

    protected TemplateModel getAsTemplateModel(TemplateModelRoot modelRoot) throws TemplateException {
        SimpleHash result = new SimpleHash();
        for (Iterator it = map.keySet().iterator(); it.hasNext();) {
            Expression key = (Expression) it.next();
            Expression value = (Expression) map.get(key);
            result.put(key.getStringValue(modelRoot), value.getAsTemplateModel(modelRoot));
        }
        return result;
    }

    protected boolean isTrue(TemplateModelRoot modelRoot) throws TemplateException {
        return (map != null);
    }

    protected boolean isNumerical(TemplateModelRoot modelRoot) {
        return false;
    }

    protected Number getNumericalValue(TemplateModelRoot modelRoot) throws TemplateException {
        String msg = "Error " + getLocation() + "."
            + "\nExpecting numerical value here. This is a hash.";
        throw new NonNumericalException(msg);
    }

    public String toString() {
        StringBuffer buf = new StringBuffer("{");
        for (Iterator it = map.keySet().iterator(); it.hasNext();) {
            Object key = it.next();
            Object value = map.get(key);
            buf.append(key);
            buf.append(" : ");
            buf.append(value);
            if (it.hasNext()) {
                buf.append(",");
            }
        }
        buf.append("}");
        return buf.toString();
    }
}
