/*
 * FreeMarker: a tool that allows Java programs to use templates
 * to generate HTML or other text output that contains dynamic content.
 * Copyright (C) 1998,2002 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name "Freemarker" nor any of the names of the project 
 * contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package freemarker.template.compiler;

import freemarker.template.*;
import java.io.Writer;
import java.io.IOException;
import java.util.ArrayList;

/**
 * A instruction that handles if-elseif-else blocks.
 * @author <A HREF="mailto:jon@revusky.com">Jonathan Revusky</A>
 */

final class IfBlock extends TemplateElement {

    private ArrayList conditions = new ArrayList();
    private ArrayList blocks = new ArrayList();
    private TemplateElement finalElseBlock;

    IfBlock(Expression condition, TemplateElement block) {
        addBlock(condition, block);
    }

    void addBlock(Expression condition, TemplateElement block) {
        conditions.add(condition);
        blocks.add(block);
    }

    void setFinalElseBlock(TemplateElement block) {
        finalElseBlock = block;
    }

    public void process(TemplateModelRoot modelRoot, Writer out) 
        throws TemplateException, IOException
    {
        TemplateElement block = finalElseBlock;
        for (int i = 0; i<conditions.size(); i++) {
            Expression condition = (Expression) conditions.get(i);
            if (condition.isTrue(modelRoot)) {
                block = (TemplateElement) blocks.get(i);
                break;
            }
        }
        if (block != null) {
            block.process(modelRoot, out);
        }
    }

    public String toString() {
        StringBuffer buf = new StringBuffer("<if ");
        buf.append(conditions.get(0));
        buf.append(">");
        buf.append(blocks.get(0));
        for (int i = 1; i<conditions.size(); i++) {
            buf.append("<elseif ");
            buf.append(conditions.get(i));
            buf.append(">");
            buf.append(blocks.get(i));
        }
        if (finalElseBlock != null) {
            buf.append("<else>");
            buf.append(finalElseBlock);
        }
        buf.append("</if>");
        return buf.toString();
    }
}
