/*
 * FreeMarker: a tool that allows Java programs to use templates
 * to generate HTML or other text output that contains dynamic content.
 * Copyright (C) 1998,2002 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name "Freemarker" nor any of the names of the project 
 * contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package freemarker.template.compiler;

import freemarker.template.*;
import java.io.Writer;
import java.io.IOException;
import java.util.List;
import java.util.Iterator;

/**
 * Encapsulates an array of <tt>TemplateElement</tt> objects. 
 */
final class NestedTemplateElements extends TemplateElement {

    private TemplateElement[] elements = new TemplateElement[0];

    /**
     * Create a new NestedTemplateElements object, given a list of
     * <tt>TemplateElement</tt>s to build the internal data structure.
     *
     * @param processorList a <tt>List</tt> of <tt>TemplateElement</tt>
     * objects to be added to the internal list.
     */
    NestedTemplateElements( List elementList ) {
        elements = (TemplateElement[]) elementList.toArray(elements);
    }

    /**
     * Processes the contents of the internal <tt>TemplateElement</tt> list,
     * and outputs the resulting text to a <tt>Writer<tt>.
     */
    public void process(TemplateModelRoot modelRoot, Writer out)
        throws TemplateException, IOException
    {
        for (int i=0; i<elements.length; i++) {
            elements[i].process(modelRoot, out);
        }
    }

    public String toString() {
        StringBuffer buf = new StringBuffer();
        for (int i = 0; i<elements.length; i++) {
            buf.append(elements[i]);
        }
        return buf.toString();
    }
}
