/*
 * FreeMarker: a tool that allows Java programs to use templates
 * to generate HTML or other text output that contains dynamic content.
 * Copyright (C) 1998,2002 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name "Freemarker" nor any of the names of the project 
 * contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package freemarker.template.compiler;

import freemarker.template.*;

/**
 * Objects that represent instructions or expressions
 * in the compiled tree representation of the template
 * all descend from this abstract root class.
 */
abstract class TemplateObject {

    int line = -1, column = -1;
    String templateName = "template";

    TemplateObject() {
    }

    TemplateObject(String templateName, 
                    int line,
                    int column) 
    {
        this.templateName = templateName;
        this.line = line;
        this.column = column;
    }

    /**
     * Used to set the location info in this template object
     */
    void setLocation(Template template, Token tok) {
        this.templateName = template.getName();
        this.line = tok.beginLine;
        this.column = tok.beginColumn;
    }

    /**
     * Used to set the location info in this template object
     */
    void setLocation(TemplateObject obj) {
        this.templateName = obj.templateName;
        this.line = obj.line;
        this.column = obj.column;
    }

    /**
     * Returns a string that indicates
     * where in the template source, this object is.
     */
    String getLocation() {
        return "on line " 
               + line 
               + ", column " 
               + column 
               + " in template: " 
               + templateName;
    }
}
