/*
 * FreeMarker: a tool that allows Java programs to use templates
 * to generate HTML or other text output that contains dynamic content.
 * Copyright (C) 1998,2002 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name "Freemarker" nor any of the names of the project 
 * contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package freemarker.testcase;

import junit.framework.*;

/**
 * Test suite for FreeMarker. The suite conforms to interface expected by
 * <a href="http://junit.sourceforge.net/" target="_top">JUnit</a>.
 *
 * @version $Id: FreeMarkerTestSuite.java,v 1.36 2002/04/16 19:17:57 revusky Exp $
 */
public class FreeMarkerTestSuite {

    public static Test suite() {
        TestSuite suite = new TestSuite();

        suite.addTest( new DummyTestCase( "dummyTestCase" ));
        suite.addTest( new TestComment( "commentTest" ));
        suite.addTest( new TestVariables( "variableTest" ));
        suite.addTest( new TestBoolean( "booleanTest" ));
        suite.addTest( new TestMultiModels( "multiModelTest" ));
        suite.addTest( new TestNoParse( "noParseTest" ));
        suite.addTest( new TestTransform( "transformTest" ));
        suite.addTest( new TestCompress( "compressionTest" ));
        suite.addTest( new TestLastCharacter( "lastCharacterTest" ));
        suite.addTest( new TestListIterators( "listIteratorTest" ));
        suite.addTest( new TestListLiteral( "listLiteralTest" ));
        suite.addTest( new TestHashLiteral( "hashLiteralTest" ));
        suite.addTest( new TestNumberLiteral( "numberLiteralTest" ));
        suite.addTest( new TestNewlines1( "newlineTest1" ));
        suite.addTest( new TestNewlines2( "newlineTest2" ));
        suite.addTest( new TestComparisons( "comparisonTest" ));
        suite.addTest( new TestJavaTransform( "javaToHtmlTest" ));
        suite.addTest( new TestFreeMarkerTransform( "freeMarkerToHtmlTest" ));
        suite.addTest( new TestIdentifier( "testIdentifier" ));
        suite.addTest( new TestPrecedence( "testPrecedence" ));
        suite.addTest( new TestFunction( "testFunction" ));
        suite.addTest( new TestSwitchCase( "testSwitchCase" ));
        suite.addTest( new TestExtendedList( "testExtendedList" ));
        suite.addTest( new TestBeans( "testBeans" ));
        suite.addTest( new TestArithmetic("testArithmetic"));

        // This could be problematic, since it assumes a particular ordering
        // for keysets and values from a hash, which are ultimately
        // dependant on the implementation of the underlying JVM class library.
        //suite.addTest( new TestExtendedHash( "testExtendedHash" ));

        // These tests depend on the properties file being set up correctly
        suite.addTest( new TestLocalization( "testLocale" ));
        suite.addTest( new TestInclude( "testInclude" ));

//        This test is screwy because the line numbers in the
//        stack trace are always changing.
//        suite.addTest( new TestInclude2( "testInclude2" ));

        // These tests are problematic in an automatic suite --
        // commenting out for now.
        //suite.addTest( new TestException( "exceptionTest" ));
        //suite.addTest( new TestExecModel( "execTest" ));

        return suite;
    }

    public static void main (String[] args) {
        junit.swingui.TestRunner.run ( FreeMarkerTestSuite.class );
    }
}
