/*
 * FreeMarker: a tool that allows Java programs to use templates
 * to generate HTML or other text output that contains dynamic content.
 * Copyright (C) 1998,2002 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name "Freemarker" nor any of the names of the project 
 * contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package freemarker.testcase;

import java.io.IOException;
import java.io.StringReader;
import java.io.StringWriter;
import java.util.Arrays;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.HashMap;
import java.util.Map;
import java.util.ResourceBundle;

import junit.framework.TestResult;

import freemarker.ext.beans.RootMapModel;
import freemarker.ext.beans.ResourceBundleModel;
import freemarker.ext.beans.StaticModels;
import freemarker.template.*;
import freemarker.template.utility.CompressWhitespace;
import freemarker.template.utility.LegacyCompress;

/**
 * @author Attila Szegedi, szegedia at freemail dot hu
 * @version $Id: TestBeans.java,v 1.2 2002/03/23 05:53:02 run2000 Exp $
 */
public class TestBeans extends AbstractTestCase
{
	public TestBeans(String name)
	{
	    super(name);
	}
	
    private TemplateModelRoot modelRoot;

    /**
     * Set up the test case prior to running.
     */
    public void setUp() 
    {
        setUpFiles( "test-beans.html" );

		Map map = new HashMap();
		map.put("array", new String[] { "array-0", "array-1" });
		map.put("list", Arrays.asList(new String[] { "list-0", "list-1", "list-2" }));
		Map tmap = new HashMap();
		tmap.put("key", "value");
		Object objKey = new Object();
		tmap.put(objKey, "objValue");
		map.put("map", tmap);
		map.put("objKey", objKey);
		map.put("obj", new freemarker.testcase.models.BeanTestClass());
		map.put("resourceBundle", new ResourceBundleModel(ResourceBundle.getBundle("freemarker.testcase.models.BeansTestResources")));
		map.put("date", new GregorianCalendar(1974, 10, 14).getTime());
		map.put("statics", StaticModels.INSTANCE);
		
        modelRoot = new SimpleHash();
        modelRoot.put("message", new SimpleScalar("Hello, world!"));

        modelRoot = new RootMapModel(map);
    }

    /**
     * Abstract method for performing the test. The implementing class should
     * indicate clearly whether the test has passed. A pass result should be
     * written to screen. A fail result should also generate information about
     * the failure.
     */
    public void runTest() throws TemplateException, IOException {
        Template cTemplate;
        StringWriter sw = new StringWriter();
        cTemplate = new Template( new StringReader( m_aTemplateText ));
        // Process the template.
        cTemplate.process(modelRoot, sw);
        showTestResults( m_aReferenceText, sw.toString() );
    }

    /** Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestCompress( "test-compress.html" );
        TestResult cResults = new TestResult();

        cTest.run();
    }
}
