/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.template.utility.*;
import java.io.IOException;
import java.io.StringWriter;
import java.io.StringReader;
import junit.framework.*;

/** Test class for performing tests on the numeric comparison operations
 * in the <tt>freemarker.template.utility</tt> package.
 *
 * @version $Id: TestComparisons.java,v 1.5 2002/03/23 05:53:02 run2000 Exp $
 */
public class TestComparisons extends AbstractTestCase {
    protected SimpleHash modelRoot;

    /** Create a new TestMultiModels test case */
    public TestComparisons(String aTestname) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-comparisons.html" );

        // Make a template data model.
        modelRoot = new SimpleHash();
        modelRoot.put("message", new SimpleScalar( "Hello, world!" ));
        modelRoot.put("zero", new SimpleNumber(new Integer( 0 )));
    }

    /**
     * Abstract method for performing the test. The implementing class should
     * indicate clearly whether the test has passed. A pass result should be
     * written to screen. A fail result should also generate information about
     * the failure.
     */
    public void runTest() throws TemplateException, IOException {
        Template cTemplate;
        StringWriter sw = new StringWriter();
        cTemplate = new Template( new StringReader( m_aTemplateText ));
        // Process the template.
        cTemplate.process(modelRoot, sw);
        showTestResults( m_aReferenceText, sw.toString() );
    }

    /** Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestComparisons( "test-comparisons.html" );
        TestResult cResults = new TestResult();

        cTest.run( cResults );
    }
}
