/*
 * FreeMarker: a tool that allows Java programs to use templates
 * to generate HTML or other text output that contains dynamic content.
 * Copyright (C) 1998,2002 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name "Freemarker" nor any of the names of the project 
 * contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package freemarker.testcase;

import freemarker.template.*;
import java.io.IOException;
import java.io.StringWriter;
import java.io.StringReader;
import junit.framework.*;

/** Test class for testing FreeMarker's functions (also known as Macros under
 * different template engines). Runs through a series of tests to see
 * what happens under unusual circumstances.
 *
 * @version $Id: TestFunction.java,v 1.5 2002/03/23 05:53:02 run2000 Exp $
 */
public class TestFunction extends AbstractTestCase {
    protected SimpleHash    modelRoot;

    public TestFunction(String aTestname) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-function.html" );

        // Make a template data model.
        modelRoot = new SimpleHash();
        modelRoot.put("message", new SimpleScalar("Hello, world!"));

        SimpleHash urls = new SimpleHash();
        urls.put( "home", "/home.html" );
        urls.put( "about", "/about.html" );
        modelRoot.put( "urls", urls );

        SimpleHash images = new SimpleHash();
        images.put( "home", "/images/home.png" );
        images.put( "about", "/image/about-us.jpeg" );
        modelRoot.put( "images", images );

        SimpleHash prefs = new SimpleHash();
        prefs.put( "showImages", true );
        modelRoot.put( "preferences", prefs );
    }

    /**
     * Abstract method for performing the test. The implementing class should
     * indicate clearly whether the test has passed. A pass result should be
     * written to screen. A fail result should also generate information about
     * the failure.
     */
    public void runTest() throws TemplateException, IOException {
        Template cTemplate;
        StringWriter sw = new StringWriter();
        try {
            cTemplate = new Template( new StringReader( m_aTemplateText ));
        } catch( IOException e ) {
            fail( e.getMessage() );
            return;
        }

        // Process the template.
        cTemplate.process(modelRoot, sw);
        showTestResults( m_aReferenceText, sw.toString() );
    }

    /** Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestFunction( "test-function.html" );
        TestResult cResults = new TestResult();

        cTest.run();
    }
}
