/*
 * FreeMarker: a tool that allows Java programs to use templates
 * to generate HTML or other text output that contains dynamic content.
 * Copyright (C) 1998,2002 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name "Freemarker" nor any of the names of the project 
 * contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.testcase.models.*;
import java.io.IOException;
import java.io.StringWriter;
import java.io.StringReader;
import junit.framework.*;
import java.util.Locale;

/** Test class for testing FreeMarker's number literal syntax.
 *
 * @version $Id: TestNumberLiteral.java,v 1.7 2002/04/30 13:29:24 revusky Exp $
 */
public class TestNumberLiteral extends AbstractTestCase {
    protected SimpleHash    modelRoot;

    /** Create a new TestNumberLiteral test case */
    public TestNumberLiteral( String aTestname ) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-numberliteral.html" );

        // Make a template data model.
        SimpleHash cModel1 = new SimpleHash();

        cModel1.put("1", "one");
        cModel1.put("12", "twelve");
        cModel1.put( "2one", "two-one" );
        cModel1.put( "one2", "one-two" );

        SimpleList cModel2 = new SimpleList();

        cModel2.add( "zero" );
        cModel2.add( "one" );
        cModel2.add( "two" );
        cModel2.add( "three" );
        cModel2.add( "four" );
        cModel2.add( "five" );
        cModel2.add( "six" );
        cModel2.add( "seven" );
        cModel2.add( "eight" );
        cModel2.add( "nine" );
        cModel2.add( "tenth" );
        cModel2.add( "eleven" );
        cModel2.add( "twelve" );

        modelRoot = new SimpleHash();
        modelRoot.put("message", "Hello, world!");
        modelRoot.put("foo", "bar");
        modelRoot.put("one", "1");
        modelRoot.put("1", "one");
        modelRoot.put("12", "twelve");
        modelRoot.put("2one", "two-one");
        modelRoot.put("one2", "one-two");
        modelRoot.put("hash", cModel1);
        modelRoot.put("list", cModel2);
        modelRoot.put("call", new SimpleTestMethod() );
    }

    /**
     * Abstract method for performing the test. The implementing class should
     * indicate clearly whether the test has passed. A pass result should be
     * written to screen. A fail result should also generate information about
     * the failure.
     */
    public void runTest() throws TemplateException, IOException {
        Template cTemplate;
        StringWriter sw = new StringWriter();
        try {
            cTemplate = new Template( new StringReader( m_aTemplateText ));
            cTemplate.setLocale(Locale.FRANCE);
        } catch( IOException e ) {
            fail( e.getMessage() );
            return;
        }

        // Process the template.
        cTemplate.process(modelRoot, sw);
        showTestResults( m_aReferenceText, sw.toString() );
    }

    /** Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestNumberLiteral( "test-numberliteral.html" );
        TestResult cResults = new TestResult();

        cTest.run();
    }
}
