/*
 * FreeMarker: a tool that allows Java programs to use templates
 * to generate HTML or other text output that contains dynamic content.
 * Copyright (C) 1998,2002 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name "Freemarker" nor any of the names of the project 
 * contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package freemarker.testcase;

import freemarker.template.*;
import java.io.*;
import junit.framework.*;

/** Test class for testing FreeMarker variable, in particular, the chaining
 * of variables using dot and dynamic-key-name.
 *
 * @version $Id: TestVariables.java,v 1.5 2002/03/23 05:53:02 run2000 Exp $
 */
public class TestVariables extends AbstractTestCase {
    protected SimpleHash    modelRoot;

    /** Create a new TestVariables test case */
    public TestVariables(String aTestname) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-variables.html" );

        // Make a template data model.
        modelRoot = new SimpleHash();
        modelRoot.put("message", new SimpleScalar("Hello, world!"));

        SimpleList cModel1 = new SimpleList();
        SimpleHash cModel2 = new SimpleHash();
        SimpleHash cModel3 = new SimpleHash();
        SimpleHash cModel4 = new SimpleHash();

        cModel1.add( "one" );
        cModel1.add( "two" );
        cModel1.add( "three" );
        cModel1.add( "four" );
        cModel1.add( "five" );

        cModel2.put( "output", new SimpleScalar( "My message." ));
        cModel2.put( "key", cModel1 );
        cModel3.put( "value", cModel2 );
        cModel4.put( "mykey", "key" );
        cModel4.put( "_test", "out" );

        modelRoot.put( "list", cModel1 );
        modelRoot.put( "hash", cModel2 );
        modelRoot.put( "hash2", cModel3 );
        modelRoot.put( "items", cModel4 );
    }

    /**
     * Abstract method for performing the test. The implementing class should
     * indicate clearly whether the test has passed. A pass result should be
     * written to screen. A fail result should also generate information about
     * the failure.
     */
    public void runTest() throws TemplateException, IOException {
        Template cTemplate;
        StringWriter sw = new StringWriter();

        try {
            cTemplate = new Template( new StringReader( m_aTemplateText ));
        } catch( IOException e ) {
            fail( e.getMessage() );
            return;
        }

        // Process the template.
        cTemplate.process(modelRoot, sw);
        showTestResults( m_aReferenceText, sw.toString() );
    }

    /** Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestVariables( "test-variables.html" );
        TestResult cResults = new TestResult();

        cTest.run();
    }
}
